@@ -36,6 +36,26 @@ QueueAttributeFilterType = TypeLiteral(
         "SenderId",
         "SentTimestamp",
         "SequenceNumber",
+        "Policy",
+        "VisibilityTimeout",
+        "MaximumMessageSize",
+        "MessageRetentionPeriod",
+        "ApproximateNumberOfMessages",
+        "ApproximateNumberOfMessagesNotVisible",
+        "CreatedTimestamp",
+        "LastModifiedTimestamp",
+        "QueueArn",
+        "ApproximateNumberOfMessagesDelayed",
+        "DelaySeconds",
+        "ReceiveMessageWaitTimeSeconds",
+        "RedrivePolicy",
+        "FifoQueue",
+        "ContentBasedDeduplication",
+        "KmsMasterKeyId",
+        "KmsDataKeyReusePeriodSeconds",
+        "DeduplicationScope",
+        "FifoThroughputLimit",
+        "RedriveAllowPolicy",
         "SqsManagedSseEnabled",
     ],
 )
